@@ -1,6 +1,6 @@
 # ABSTRACT: get novel content from website 小说站点解析引擎
 package  Novel::Robot::Parser;
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 use Novel::Robot::Browser;
 use URI;
 use Encode;
@@ -250,119 +250,3 @@ sub get_chapter_ids {
 
 1;
 
-=pod
-
-=encoding utf8
-
-=head1 NAME
-
-L<Novel::Robot::Parser> 小说站点解析引擎
-
-=head1 INIT
-
-=head2 site 支持小说站点名称
-
-晋江：L<Jjwxc|http://www.jjwxc.net>
-
-豆豆：L<Dddbbb|http://www.dddbbb.net>
-
-努努：L<Nunu|http://book.kanunu.org>
-
-书农：L<Shunong|http://book.shunong.com>
-
-爱尚：L<Asxs|http://www.23hh.com>
-
-落秋：L<Luoqiu|http://www.luoqiu.com>
-
-顶点：L<Dingdian|http://www.23us.com>
-
-=head2 new
-
-初始化解析模块
-
-   my $url = 'http://www.jjwxc.net/onebook.php?novelid=2456';
-
-   #直接指定站点
-   my $parser = Novel::Robot::Parser->new( site => 'Jjwxc' );
-    
-   #通过url自动检测站点
-   my $parser = Novel::Robot::Parser->new( site => $url );
-
-   $parser->get_index_ref($url);
-
-=head1 INDEX FUNCTION
-
-=head2 get_index_ref 获取目录页信息
-
-    my $index_ref = $parser->get_index_ref($index_url, %opt);
-
-=head2 parse_index 解析目录页
-
-   my $index_ref = $parser->parse_index($index_html_ref);
-
-=head2 update_chapter_id 更新章节id
-
-  $parser->update_chapter_id($index_ref);
-
-=head2 update_chapter_num 更新章节数
-
-  $parser->update_chapter_num($index_ref);
-
-=head1 CHAPTER FUNCTION
-
-=head2 get_chapter_ref 获取章节页信息
-
-    my $chapter_url = 'http://www.jjwxc.net/onebook.php?novelid=2456&chapterid=2';
-    my $chapter_ref = $parser->get_chapter_ref($chapter_url, 2);
-
-=head2 parse_chapter 解析章节页
-  
-   my $chapter_ref = $parser->parse_chapter($chapter_html_ref);
-
-=head1 WRITER FUNCTION
-
-=head2 get_writer_ref 获取作者页信息
-
-    my $writer_url = 'http://www.jjwxc.net/oneauthor.php?authorid=3243';
-    my $writer_ref = $parser->get_writer_ref($writer_url);
-
-=head2 parse_writer 解析作者页
-
-   my $writer_ref = $parser->parse_writer($writer_html_ref);
-
-=head1 QUERY FUNCTION
-
-=head2 get_query_ref 获取查询结果
-
-    my $query_type = '作者';
-    my $query_value = '顾漫';
-    my $query_ref = $parser->get_query_ref($query_type, $query_value);
-
-=head2 make_query_request 指定查询请求
-
-  #查询类型：  $type
-  #查询关键字：$keyword
-  my ($query_url, $post_data) = 
-        $parser->make_query_request( $type, $keyword );
-
-=head2 parse_query 解析查询结果
-
-  my $query_ref = $parser->parse_query($query_html_ref); 
-
-=head2 parse_query_result_urls 查询结果为分页url
-
-  my $query_urls_ref = $parser->parse_query_result_urls($query_html_ref);
-
-=head1 OTHER FUNCTION 
-
-=head2 get_inner_html 获取html元素的innerHTML
-
-  my $inner_html = $parser->get_inner_html($element);
-
-=head2 format_abs_url 批量将url转换成绝对路径
-
-  $parser->format_abs_url($index_ref->{chapter_info}, $index_ref->{index_url});
-  $parser->format_abs_url($index_ref->{more_book_info}, $index_ref->{index_url});
-  $parser->format_abs_url($query_urls_ref, $query_url);
-
-=cut
